# Regional comparisons

# Subregions
# - Iberian Peninsula (IBE): Portugal, Spain
# - France and Italy (IAF)
# - Balkan Peninsula (BAL): Albania, Bosnia and Herzegovina, Croatia, Greece, North Macedonia and Montenegro
# - Cyprus and Turkey (TAC)
# - Southeastern Mediterranean (SEM):  Israel and Palestinian territories, Lebanon, Libya, Syria
# - Northwest Africa (NWA): Algeria, Morocco, Tunisia

library(raster)
library(rgdal)

path_data <- message("insert path here")
path_workspaces <- message("insert path here")

border <- readOGR(paste0(path_data,'ne_50m_admin_0_countries/ne_50m_admin_0_countries.shp')) # from https://www.naturalearthdata.com/downloads/50m-cultural-vectors/50m-admin-0-countries-2/	
sm_monthly_brick <- brick(paste0(path_workspaces,"sm79_19_monthly.nc", varname="sm")) # created with cdo
coord <- coordinates(sm_monthly_brick)
load(file=paste0(path_workspaces,"locat.RData")) # from Land_cover.Rmd
border_crop <- crop(border,extent(sm_monthly_brick))
# attribute each pixel to a country
countries <- vector("list",length=length(border_crop@data$SOVEREIGNT))
for (i in 1:length(border_crop@data$SOVEREIGNT)){
  countries[[i]] <- subset(x=border, subset=border@data[["SOVEREIGNT"]] == border_crop@data$SOVEREIGNT[i])
}
names(countries) <- as.character(border_crop@data$SOVEREIGNT)

border_crop@data$SOVEREIGNT
IBE <- aggregate(rbind(countries[["Spain"]],countries[["Portugal"]]))
IAF <- aggregate(rbind(countries[["Italy"]],countries[["France"]]))
BAL <- aggregate(rbind(countries[["Albania"]],countries[["Bosnia and Herzegovina"]],countries[["Croatia"]],countries[["Greece"]],countries[["Macedonia"]],countries[["Montenegro"]],countries[["Bulgaria"]]))
TAC <- aggregate(rbind(countries[["Turkey"]],countries[["Cyprus"]]))
SEM <- aggregate(rbind(countries[["Israel"]],countries[["Lebanon"]],countries[["Libya"]],countries[["Syria"]],countries[["Jordan"]],countries[["Iraq"]],countries[["Iran"]]))
NWA <- aggregate(rbind(countries[["Algeria"]],countries[["Morocco"]],countries[["Tunisia"]]))
plot(NWA)

spat_point <- SpatialPoints(coord[locat,],proj4string=crs(IBE))
spat_point_region <- vector("list",6)
i <- 1
for (region in c(IBE,IAF,BAL,TAC,SEM,NWA)){
  spat_point_region[[i]] <- crop(spat_point,region)
  i <- i+1
}
names(spat_point_region) <- c("IBE","IAF","BAL","TAC","SEM","NWA")


plot(spat_point_region[[1]])
plot(spat_point_region[[2]])
plot(spat_point_region[[3]])
plot(spat_point_region[[4]])
plot(spat_point_region[[5]])
plot(spat_point_region[[6]])

coord_all <- paste(spat_point@coords[,1],spat_point@coords[,2])

coord_region <- vector("list",6)
i <- 1
for (region in c(IBE,IAF,BAL,TAC,SEM,NWA)){
  coord_region[[i]] <- paste(spat_point_region[[i]]@coords[,1],spat_point_region[[i]]@coords[,2])
  i <- i+1
}
names(coord_region) <- c("IBE","IAF","BAL","TAC","SEM","NWA")


# Identify and insert missing pixels ####
#########################################
coord_missing <- coord_all[-which(coord_all %in% unlist(coord_region))] # identify missing pixels
coord_missing <- unlist(strsplit(coord_missing, " "))
coord_missing <- t(matrix(as.numeric(coord_missing),2,4))
plot(SpatialPoints(coord_missing))
spat_point_region[[3]]@coords <- rbind(spat_point_region[[3]]@coords, coord_missing)

# Repetition from above: now including the missing pixels
coord_region <- vector("list",6)
i <- 1
for (region in c(IBE,IAF,BAL,TAC,SEM,NWA)){
  coord_region[[i]] <- paste(spat_point_region[[i]]@coords[,1],spat_point_region[[i]]@coords[,2])
  i <- i+1
}
names(coord_region) <- c("IBE","IAF","BAL","TAC","SEM","NWA")


coord_region_ind <- vector("list",6)
i <- 1
for (region in c(IBE,IAF,BAL,TAC,SEM,NWA)){
  coord_region_ind[[i]] <- match(coord_region[[i]],coord_all)
  i <- i+1
}
names(coord_region_ind) <- c("IBE","IAF","BAL","TAC","SEM","NWA")


reg_id <- rep(NA,length(locat))
reg_id[coord_region_ind$IBE] <- "IBE"
reg_id[coord_region_ind$IAF] <- "IAF"
reg_id[coord_region_ind$BAL] <- "BAL"
reg_id[coord_region_ind$TAC] <- "TAC"
reg_id[coord_region_ind$SEM] <- "SEM"
reg_id[coord_region_ind$NWA] <- "NWA"
sum(table(reg_id)) 
save(reg_id,coord_region_ind,file=paste0(path_workspaces,"Regional_indices.RData"))